# Giskard

A random collection of tools I find useful for data science. A.K.A. my helpful robot 
companion (the name comes from the [*Robot* series](https://en.wikipedia.org/wiki/List_of_Robot_series_characters#R._Giskard_Reventlov)).

For the most part these are functions, classes, etc. that I have found useful in more
than one project, so I decided to make a package for them for my own sanity. Some of
these functions may be PRed upstream eventually, others may not. If you find anything 
in here useful please let me know as that is the best motivation to PR that 
functionality into a "real" repo. If you find any issues or bugs, feel free to 
[make an issue](https://github.com/bdpedigo/giskard/issues).

## Installation
Since I make changes to this code often I recommend installing in develop mode.
To clone from GitHub and install, from the command line do:
```
git clone https://github.com/bdpedigo/giskard.git
cd giskard
pip install -e .
```
